##
##  meson.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         meson
Summary:      Meson Build System
URL:          http://mesonbuild.com/
Vendor:       Meson Development Team
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        SCM
License:      Apache
Version:      1.7.2
Release:      20250405

#   list of sources
Source0:      https://github.com/mesonbuild/meson/archive/%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  python, python::with_lzma = yes, python-setup, ninja
PreReq:       python, python::with_lzma = yes, python-setup, ninja

%description
    Meson is an open source build system meant to be both extremely
    fast, and, even more importantly, as user friendly as possible. The
    main design point of Meson is that every moment a developer spends
    writing or debugging build definitions is a second wasted. So is
    every second spent waiting for the build system to actually start
    compiling code. The features are: multiplatform support for Linux,
    macOS, Windows, GCC, Clang, Visual Studio and others; supported
    languages include C, C++, D, Fortran, Java, Rust; build definitions
    in a very readable and user friendly non-Turing complete DSL; cross
    compilation for many operating systems as well as bare metal;
    optimized for extremely fast full and incremental builds without
    sacrificing correctness; and built-in multiplatform dependency
    provider that works together with distro packages.

%track
    prog meson = {
        version   = %{version}
        url       = https://github.com/mesonbuild/meson/releases
        regex     = tree/(__VER__)
    }

%prep
    %setup -q

%build

%install
    HOME=`pwd` %{l_prefix}/bin/python \
        -m pip install \
        --root=$RPM_BUILD_ROOT \
        --prefix=%{l_prefix} \
        --ignore-installed \
        --no-deps \
        .
    mv  $RPM_BUILD_ROOT%{l_prefix}/share/man \
        $RPM_BUILD_ROOT%{l_prefix}/man
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

